==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/ac/ac3272da788423dfee83cb3d5cb57deb.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Twig/Extension/GravatarExtension.php */
class __TwigTemplate_aa80f748ccb62e9756daadc27b42431f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Twig\\Extension;

use Mautic\\CoreBundle\\Twig\\Helper\\GravatarHelper;
use Twig\\Extension\\AbstractExtension;
use Twig\\TwigFunction;

class GravatarExtension extends AbstractExtension
{
    public function __construct(
        protected GravatarHelper \$gravatarHelper
    ) {
    }

    public function getFunctions()
    {
        return [
            new TwigFunction('gravatarGetImage', [\$this, 'getImage'], ['is_safe' => ['all']]),
        ];
    }

    public function getImage(string \$email, string \$size = '250', ?string \$default = null): string
    {
        return \$this->gravatarHelper->getImage(\$email, \$size, \$default);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Twig/Extension/GravatarExtension.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Twig/Extension/GravatarExtension.php", "/var/www/mautic-ktn/app/bundles/CoreBundle/Twig/Extension/GravatarExtension.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/ac/ac3272da788423dfee83cb3d5cb57deb.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Twig/Extension/GravatarExtension.php */
class __TwigTemplate_aa80f748ccb62e9756daadc27b42431f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Twig\\Extension;

use Mautic\\CoreBundle\\Twig\\Helper\\GravatarHelper;
use Twig\\Extension\\AbstractExtension;
use Twig\\TwigFunction;

class GravatarExtension extends AbstractExtension
{
    public function __construct(
        protected GravatarHelper \$gravatarHelper
    ) {
    }

    public function getFunctions()
    {
        return [
            new TwigFunction('gravatarGetImage', [\$this, 'getImage'], ['is_safe' => ['all']]),
        ];
    }

    public function getImage(string \$email, string \$size = '250', ?string \$default = null): string
    {
        return \$this->gravatarHelper->getImage(\$email, \$size, \$default);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Twig/Extension/GravatarExtension.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Twig/Extension/GravatarExtension.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Twig/Extension/GravatarExtension.php");
    }
}
